==> moodle-1.4.3-pgsql.tgz: moodle/lang/fr/calendar.php <==
<?php // $Id$

$string['calendar'] = 'Calendrier';
$string['calendarheading'] = 'Calendrier $a';
$string['clickhide'] = 'cacher';
$string['clickshow'] = 'afficher';
$string['confirmeventdelete'] = 'Voulez-vous vraiment supprimer cet vnement ?';
$string['courseevents'] = 'vnements d\'un cours';
$string['dayview'] = 'Vue quotidienne';
$string['daywithnoevents'] = 'Il n\'y a pas d\'vnement programms  cette date.';
$string['default'] = 'Valeur par dfaut';
$string['deleteevent'] = 'Supprimer l\'vnement';
$string['detailedmonthview'] = 'Vue mensuelle dtaille';
$string['durationminutes'] = 'Dure en minutes';
$string['durationnone'] = 'Sans dure';
$string['durationuntil'] = 'Jusqu\'au';
$string['editevent'] = 'Modifier l\'vnement';
$string['errorbeforecoursestart'] = 'Impossible de fixer un vnement avant le dbut du cours';
$string['errorinvaliddate'] = 'Date invalide';
$string['errorinvalidminutes'] = 'Indiquez une dure en minutes (un nombre 1 et 999).';
$string['errorinvalidrepeats'] = 'Indiquez un nombre d\'vnements (un nombre 1 et 99).';
$string['errornodescription'] = 'Une description est requise';
$string['errornoeventname'] = 'Le nom est requis';
$string['eventdate'] = 'Date';
$string['eventdescription'] = 'Description';
$string['eventduration'] = 'Dure';
$string['eventendtime'] = 'Fin';
$string['eventinstanttime'] = 'Heure';
$string['eventkind'] = 'Type d\'vnement';
$string['eventname'] = 'Nom';
$string['eventrepeat'] = 'Rptitions';
$string['eventsfor'] = 'vnements du $a';
$string['eventstarttime'] = 'Dbut';
$string['eventtime'] = '';
$string['eventview'] = 'Dtails de l\'vnement';
$string['expired'] = 'chu';
$string['explain_lookahead'] = 'Ce rglage dfinit combien de temps (en jours) avant le dbut effectif d\'un vnement celui-ci doit tre affich comme prochain vnement. Les vnements qui commencent aprs ce dlai ne seront pas affichs. Il n\'y a <strong>aucune garantie</strong> que tous les vnements dans cette dure soient affichs. S\'il y en a trop (c\'est--dire plus que le nombre dfini par le rglage  Nombre maximal de prochains vnements ), les vnements les plus tardifs ne seront pas affichs.';
$string['explain_maxevents'] = 'Ce rglage dfinit le nombre maximal de prochains vnements qui seront affichs. Si vous mettez ici un grand nombre, l\'affichage ne sera pas optimal.';
$string['explain_startwday'] = 'Ce rglage dfinit la faon dont les calendriers mensuels sont affichs. Utilisez-le pour choisir votre disposition prfre.';
$string['explain_timeformat'] = 'Ce rglage dfinit l\'affichage des heures dans le calendrier. Vous pouvez choisir le format 12 heures ou 24 heures. Si vous choisissez  Valeur par dfaut , le format sera celui dfini par la langue que vous utilisez dans le site.';
$string['globalevents'] = 'vnements globaux';
$string['groupevents'] = 'vnements de groupe';
$string['gotocalendar'] = 'Aller au calendrier';
$string['hidden'] = 'cachs';
$string['manyevents'] = '$a vnements ';
$string['monthlyview'] = 'Vue mensuelle';
$string['newevent'] = 'Nouvel vnement';
$string['noupcomingevents'] = 'Il n\'y a pas de prochain vnement';
$string['oneevent'] = '1 vnement';
$string['pref_lookahead'] = 'Anticipation des prochains vnements';
$string['pref_maxevents'] = 'Nombre maximal de prochains vnements';
$string['pref_startwday'] = 'Premier jour de la semaine';
$string['pref_timeformat'] = 'Format d\'affichage des heures';
$string['preferences'] = 'Rglages';
$string['preferences_available'] = 'Vos rglages personnels';
$string['repeatnone'] = 'Sans rptition';
$string['repeatweeksl'] = 'Rptition hebdomadaire, cration de tous les ';
$string['repeatweeksr'] = 'vnements';
$string['shown'] = 'affichs';
$string['spanningevents'] = 'vnements en cours';
$string['timeformat_12'] = '12 heures (am/pm)';
$string['timeformat_24'] = '24 heures';
$string['today'] = 'Aujourd\'hui';
$string['tomorrow'] = 'Demain';
$string['tt_deleteevent'] = 'Supprimer l\'vnement';
$string['tt_editevent'] = 'Modifier l\'vnement';
$string['tt_hidecourse'] = 'vnements des cours affichs (cliquer pour cacher)';
$string['tt_hideglobal'] = 'vnements globaux affichs (cliquer pour cacher)';
$string['tt_hidegroups'] = 'vnements des groupes affichs (cliquer pour cacher)';
$string['tt_hideuser'] = 'vnements privs affichs (cliquer pour cacher)';
$string['tt_showcourse'] = 'vnements des cours cachs (cliquer pour afficher)';
$string['tt_showglobal'] = 'vnements globaux cachs (cliquer pour afficher)';
$string['tt_showgroups'] = 'vnements des groupes cachs (cliquer pour afficher)';
$string['tt_showuser'] = 'vnements privs cachs (cliquer pour afficher)';
$string['typecourse'] = 'vnement d\'un cours';
$string['typegroup'] = 'vnement de groupe';
$string['typesite'] = 'vnement global';
$string['typeuser'] = 'vnement priv';
$string['upcomingevents'] = 'Prochains vnements';
$string['userevents'] = 'vnements privs';
$string['yesterday'] = 'Hier';

$string['sun'] = 'Dim';
$string['mon'] = 'Lun';
$string['tue'] = 'Mar';
$string['wed'] = 'Mer';
$string['thu'] = 'Jeu';
$string['fri'] = 'Ven';
$string['sat'] = 'Sam';
$string['sunday'] = 'Dimanche';
$string['monday'] = 'Lundi';
$string['tuesday'] = 'Mardi';
$string['wednesday'] = 'Mercredi';
$string['thursday'] = 'Jeudi';
$string['friday'] = 'Vendredi';
$string['saturday'] = 'Samedi';

$string['pref_dstpreset'] = 'Heure d\'t';
$string['notusingdst'] = 'Heure d\'t non utilise';
$string['dstpresetname'] = 'Nom du rglage';
$string['dstpresetactivated'] = 'Activation';
$string['dstpresetdeactivated'] = 'Dsactivation';
$string['dstpresetadjusttime'] = 'Ajustement';
  	 
$string['explain_dstpresetforced'] = 'L\'administrateur du site ne permet pas aux utilisateurs de modifier ce rglage.';
$string['explain_dstpreset'] = 'Vous pouvez choisir dans le menu droulant votre rglage de l\'heure d\'t.';
$string['dstdefaultpresetname'] = 'Nouveau rglage heure d\'t';
$string['nth'] = '{$a}er';
$string['dsthumanreadable'] = 'Le $a->activate_index $a->activate_weekday de $a->activate_month, $a->direction de $a->offset minutes. Ce changement dure jusqu\'au $a->deactivate_index $a->deactivate_weekday de $a->deactivate_month.';
$string['dstadjusttime'] = ''; //'Changer l\'heure';
$string['dstof'] = 'de';
$string['dstat'] = '';
$string['dstonthe'] = 'Le';
$string['dstby'] = 'de';
$string['day'] = 'jour';
$string['timeforward'] = 'Avancer l\'heure';
$string['timerewind'] = 'Retarder l\'heure';
$string['first'] = 'premier';
$string['last'] = 'dernier';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/fr/calendar.php <==
<?php // $Id$

$string['calendar'] = 'Calendrier';
$string['calendarheading'] = 'Calendrier $a';
$string['clickhide'] = 'cacher';
$string['clickshow'] = 'afficher';
$string['confirmeventdelete'] = 'Voulez-vous vraiment supprimer cet vnement ?';
$string['courseevents'] = 'vnements de cours';
$string['dayview'] = 'Vue quotidienne';
$string['daywithnoevents'] = 'Il n\'y a pas d\'vnement programms  cette date.';
$string['default'] = 'Valeur par dfaut';
$string['deleteevent'] = 'Supprimer l\'vnement';
$string['detailedmonthview'] = 'Vue mensuelle dtaille';
$string['durationminutes'] = 'Dure en minutes';
$string['durationnone'] = 'Sans dure';
$string['durationuntil'] = 'Jusqu\'au';
$string['editevent'] = 'Modifier l\'vnement';
$string['errorbeforecoursestart'] = 'Impossible de fixer un vnement avant le dbut du cours';
$string['errorinvaliddate'] = 'Date invalide';
$string['errorinvalidminutes'] = 'Indiquez une dure en minutes (un nombre 1 et 999).';
$string['errorinvalidrepeats'] = 'Indiquez un nombre d\'vnements (un nombre 1 et 99).';
$string['errornodescription'] = 'Une description est requise';
$string['errornoeventname'] = 'Le nom est requis';
$string['eventdate'] = 'Date';
$string['eventdescription'] = 'Description';
$string['eventduration'] = 'Dure';
$string['eventendtime'] = 'Fin';
$string['eventinstanttime'] = 'Heure';
$string['eventkind'] = 'Type d\'vnement';
$string['eventname'] = 'Nom';
$string['eventrepeat'] = 'Rptitions';
$string['eventsfor'] = 'vnements du $a';
$string['eventstarttime'] = 'Dbut';
$string['eventtime'] = '';
$string['eventview'] = 'Dtails de l\'vnement';
$string['expired'] = 'chu';
$string['explain_lookahead'] = 'Ce rglage dfinit combien de temps (en jours) avant le dbut effectif d\'un vnement celui-ci doit tre affich comme prochain vnement. Les vnements qui commencent aprs ce dlai ne seront pas affichs. Il n\'y a <strong>aucune garantie</strong> que tous les vnements dans cette dure soient affichs. S\'il y en a trop (c\'est--dire plus que le nombre dfini par le rglage  Nombre maximal de prochains vnements ), les vnements les plus tardifs ne seront pas affichs.';
$string['explain_maxevents'] = 'Ce rglage dfinit le nombre maximal de prochains vnements qui seront affichs. Si vous mettez ici un grand nombre, l\'affichage ne sera pas optimal.';
$string['explain_persistflt'] = 'Si cette option est active, Moodle se rappellera vos derniers rglages des filtres d\'vnements et les mettra en vigueur automatiquement  chacune de vos connexions.';
$string['explain_startwday'] = 'Ce rglage dfinit la faon dont les calendriers mensuels sont affichs. Utilisez-le pour choisir votre disposition prfre.';
$string['explain_timeformat'] = 'Ce rglage dfinit l\'affichage des heures dans le calendrier. Vous pouvez choisir le format 12 heures ou 24 heures. Si vous choisissez  Valeur par dfaut , le format sera celui dfini par la langue que vous utilisez dans le site.';
$string['globalevents'] = 'vnements globaux';
$string['groupevents'] = 'vnements de groupe';
$string['gotocalendar'] = 'Aller au calendrier';
$string['hidden'] = 'cachs';
$string['manyevents'] = '$a vnements ';
$string['monthlyview'] = 'Vue mensuelle';
$string['newevent'] = 'Nouvel vnement';
$string['noupcomingevents'] = 'Il n\'y a pas de prochain vnement';
$string['oneevent'] = '1 vnement';
$string['pref_lookahead'] = 'Anticipation des prochains vnements';
$string['pref_maxevents'] = 'Nombre maximal de prochains vnements';
$string['pref_persistflt'] = 'Enregistrer les rglages des filtres';
$string['pref_startwday'] = 'Premier jour de la semaine';
$string['pref_timeformat'] = 'Format d\'affichage des heures';
$string['preferences'] = 'Rglages';
$string['preferences_available'] = 'Vos rglages personnels';
$string['repeateditall'] = 'Appliquer les modifications  tous les $a vvements de cette srie';
$string['repeateditthis'] = 'Appliquer les modifications  cet vnement seulement';
$string['repeatnone'] = 'Sans rptition';
$string['repeatweeksl'] = 'Rptition hebdomadaire, cration de tous les ';
$string['repeatweeksr'] = 'vnements';
$string['shown'] = 'affichs';
$string['spanningevents'] = 'vnements en cours';
$string['timeformat_12'] = '12 heures (am/pm)';
$string['timeformat_24'] = '24 heures';
$string['today'] = 'Aujourd\'hui';
$string['tomorrow'] = 'Demain';
$string['tt_deleteevent'] = 'Supprimer l\'vnement';
$string['tt_editevent'] = 'Modifier l\'vnement';
$string['tt_hidecourse'] = 'vnements des cours affichs (cliquer pour cacher)';
$string['tt_hideglobal'] = 'vnements globaux affichs (cliquer pour cacher)';
$string['tt_hidegroups'] = 'vnements des groupes affichs (cliquer pour cacher)';
$string['tt_hideuser'] = 'vnements privs affichs (cliquer pour cacher)';
$string['tt_showcourse'] = 'vnements des cours cachs (cliquer pour afficher)';
$string['tt_showglobal'] = 'vnements globaux cachs (cliquer pour afficher)';
$string['tt_showgroups'] = 'vnements des groupes cachs (cliquer pour afficher)';
$string['tt_showuser'] = 'vnements privs cachs (cliquer pour afficher)';
$string['typecourse'] = 'vnement de cours';
$string['typegroup'] = 'vnement de groupe';
$string['typesite'] = 'vnement global';
$string['typeuser'] = 'vnement priv';
$string['upcomingevents'] = 'Prochains vnements';
$string['userevents'] = 'vnements privs';
$string['yesterday'] = 'Hier';
$string['youcandeleteallrepeats'] = 'Cet vnement fait partie d\'une srie d\'vnements rpts. Vous pouvez supprimer uniquement cet vnement ou tous les $a de la srie  la fois.';

$string['sun'] = 'Di';
$string['mon'] = 'Lu';
$string['tue'] = 'Ma';
$string['wed'] = 'Me';
$string['thu'] = 'Je';
$string['fri'] = 'Ve';
$string['sat'] = 'Sa';
$string['sunday'] = 'Dimanche';
$string['monday'] = 'Lundi';
$string['tuesday'] = 'Mardi';
$string['wednesday'] = 'Mercredi';
$string['thursday'] = 'Jeudi';
$string['friday'] = 'Vendredi';
$string['saturday'] = 'Samedi';

?>
